==> istio-model-v1beta1-6.5.1-sources.jar: io/fabric8/istio/api/security/v1beta1/PeerAuthenticationListFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PeerAuthenticationListFluent<A extends PeerAuthenticationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,PeerAuthentication item);
  public A setToItems(Integer index,PeerAuthentication item);
  public A addToItems(io.fabric8.istio.api.security.v1beta1.PeerAuthentication... items);
  public A addAllToItems(Collection<PeerAuthentication> items);
  public A removeFromItems(io.fabric8.istio.api.security.v1beta1.PeerAuthentication... items);
  public A removeAllFromItems(Collection<PeerAuthentication> items);
  public A removeMatchingFromItems(Predicate<PeerAuthenticationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PeerAuthentication> getItems();
  public List<PeerAuthentication> buildItems();
  public PeerAuthentication buildItem(Integer index);
  public PeerAuthentication buildFirstItem();
  public PeerAuthentication buildLastItem();
  public PeerAuthentication buildMatchingItem(Predicate<PeerAuthenticationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PeerAuthenticationBuilder> predicate);
  public A withItems(List<PeerAuthentication> items);
  public A withItems(io.fabric8.istio.api.security.v1beta1.PeerAuthentication... items);
  public Boolean hasItems();
  public PeerAuthenticationListFluent.ItemsNested<A> addNewItem();
  public PeerAuthenticationListFluent.ItemsNested<A> addNewItemLike(PeerAuthentication item);
  public PeerAuthenticationListFluent.ItemsNested<A> setNewItemLike(Integer index,PeerAuthentication item);
  public PeerAuthenticationListFluent.ItemsNested<A> editItem(Integer index);
  public PeerAuthenticationListFluent.ItemsNested<A> editFirstItem();
  public PeerAuthenticationListFluent.ItemsNested<A> editLastItem();
  public PeerAuthenticationListFluent.ItemsNested<A> editMatchingItem(Predicate<PeerAuthenticationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,PeerAuthenticationFluent<PeerAuthenticationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> istio-model-v1beta1-6.7.2-sources.jar: io/fabric8/istio/api/security/v1beta1/PeerAuthenticationListFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PeerAuthenticationListFluent<A extends PeerAuthenticationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,PeerAuthentication item);
  public A setToItems(int index,PeerAuthentication item);
  public A addToItems(io.fabric8.istio.api.security.v1beta1.PeerAuthentication... items);
  public A addAllToItems(Collection<PeerAuthentication> items);
  public A removeFromItems(io.fabric8.istio.api.security.v1beta1.PeerAuthentication... items);
  public A removeAllFromItems(Collection<PeerAuthentication> items);
  public A removeMatchingFromItems(Predicate<PeerAuthenticationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PeerAuthentication> getItems();
  public List<PeerAuthentication> buildItems();
  public PeerAuthentication buildItem(int index);
  public PeerAuthentication buildFirstItem();
  public PeerAuthentication buildLastItem();
  public PeerAuthentication buildMatchingItem(Predicate<PeerAuthenticationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PeerAuthenticationBuilder> predicate);
  public A withItems(List<PeerAuthentication> items);
  public A withItems(io.fabric8.istio.api.security.v1beta1.PeerAuthentication... items);
  public Boolean hasItems();
  public PeerAuthenticationListFluent.ItemsNested<A> addNewItem();
  public PeerAuthenticationListFluent.ItemsNested<A> addNewItemLike(PeerAuthentication item);
  public PeerAuthenticationListFluent.ItemsNested<A> setNewItemLike(int index,PeerAuthentication item);
  public PeerAuthenticationListFluent.ItemsNested<A> editItem(int index);
  public PeerAuthenticationListFluent.ItemsNested<A> editFirstItem();
  public PeerAuthenticationListFluent.ItemsNested<A> editLastItem();
  public PeerAuthenticationListFluent.ItemsNested<A> editMatchingItem(Predicate<PeerAuthenticationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,PeerAuthenticationFluent<PeerAuthenticationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
